***************************************************************************************************************************************************************************************
*** In this dofile, we consider inference for our robustness check that controls for demographic trends. We calculate the confidence intervals using a block bootstrap approach
***************************************************************************************************************************************************************************************


clear all

use Data\Compiled\pointestrob.dta

mkmat parall1 parall2 parall3 parall4 parall5 parall6, matrix(meanestsrobcontrols)

clear


use Data\Compiled\datasnl-final.dta


encode state, gen(stateid)

gen statenr=stateid

sort statenr

merge m:1 statenr using Data\Compiled\abadieweights.dta


replace wallall2=1/35 if state=="MA"



replace wallall2=0 if wallall2==.



drop if wallall2==0




gen MA_GI=0 

replace MA_GI=1 if state=="ME" | state=="NY"  | state=="VT" | state=="WA" | state=="MA" 
*replace MA_GI=1 if state=="NJ" | state=="ME" | state=="NY"  | state=="VT" | state=="WA" | state=="MA" 

*** Generaate stateid (for clustering)



**** Normalize year to 2007

gen yearold=year

replace year=year-2007



*** Period Identfiers


gen during=0

replace during=1 if yearold==2006 | yearold==2007



gen after=0

replace after=1 if yearold>2007


**** Interaction Terms

gen MAafter=after*MA

gen MAduring=during*MA


**** Trends


gen MAyear=MA*year


gen after_year=after*year


gen during_year=during*year


gen after_MA_year=after*year*MA


gen during_MA_year=during*year*MA


sort stateid year


save Data\Compiled\bootstrap-snl-demo.dta, replace

quietly sum if year==0

local obs=r(N)






gen weightk=round(10000*wallall2*(1-1/35))

expand weightk

by state yearold, sort: gen counter=_n


gen clusterid=stateid*10000+counter

save Data\Compiled\bootstrap-snl-demo.dta, replace

*** merge controls on

drop _merge

sort yearold state

merge yearold state using Data\ACS\dataacs.dta

keep if _merge==3

drop _merge

save Data\Compiled\bootstrap-snl-demo.dta, replace

clear


******************************************************************************

program define bootreg1demo, rclass

clear

drop _all

use Data\Compiled\bootstrap-snl-demo.dta

bsample 35 , cluster(clusterid)


***

gen mem_mo_ind_rel=.

levelsof state, local(levels) 

foreach l of local levels {

quietly sum insurance300post if state=="`l'"

local Ihat=r(mean)

disp("`Ihat'")

quietly sum obsnongroup300 if state=="`l'"

local Iobs=r(mean)

disp("`Iobs'")

local Ipost=rbinomial(`Iobs', `Ihat')/`Iobs'

disp("`Ipost'")

quietly sum mem_mo_ind if yearold>2007 & yearold<=2010 & state=="`l'"

local ypostma=r(mean)

replace mem_mo_ind_rel=mem_mo_ind/`ypostma'*`Ipost' if state=="`l'" 

}
****

by stateid, sort: egen endcov_share=max(mem_mo_ind_rel)

replace mem_mo_ind_rel=mem_mo_ind_rel/endcov_share if endcov_share>1.2



* program drop slopes2

*program define slopes2, rclass

*********** derive chnages in enrollment and post-reform enrollment

 local vars "MAafter MAduring MA after during _cons"
 


 
 ********** Member Months
 
quietly reg mem_mo_ind_rel MAafter MAduring MA after during if yearold<2011, cluster(stateid) 

 foreach var of local vars {

		
local enr`var'=_b[`var']
return scalar enr`var'=`enr`var''	
		
        }


 ********** Claim Expenses
 
gen lgac=log(prov_health_serv_incur_ind_year)

quietly reg lgac MAafter MAduring MA after during if yearold<2011, cluster(stateid) 

 foreach var of local vars {

		
local claim`var'=_b[`var']
return scalar claim`var'=`claim`var''	
		
        }

********** Premiums

gen lgprem=log(prem_per_year_ind)
		 
reg lgprem MAafter MAduring MA after during if yearold<2011 , cluster(stateid)

 foreach var of local vars {

		
local prem`var'=_b[`var']
return scalar prem`var'=`prem`var''	
		
        }


***


*** control regs


 local varscon "MAafter MAduring MA after during MAafter MAduring MA after during sh1824 sh2534 sh3544 sh4554 shwomen1864 shblack1864 shwhite1864 shasian1864 unemploy1864 wage1864 _cons"

 
 ********** Member Months
 
quietly reg mem_mo_ind_rel MAafter MAduring MA after during sh1824 sh2534 sh3544 sh4554 shwomen1864 shblack1864 shwhite1864 shasian1864 unemploy1864 wage1864 if yearold<2011, cluster(stateid) 

 foreach var of local varscon {

		
local enrcon`var'=_b[`var']
return scalar enrcon`var'=`enrcon`var''	
		
        }

**** Premiums 		

quietly reg lgprem MAafter MAduring MA after during sh1824 sh2534 sh3544 sh4554 shwomen1864 shblack1864 shwhite1864 shasian1864 unemploy1864 wage1864 if yearold<2011 , cluster(stateid)

 foreach var of local varscon {

		
local premcon`var'=_b[`var']
return scalar premcon`var'=`premcon`var''	
		
        }


***

 ********** Claim Expenses

quietly reg lgac  MAafter MAduring MA after during sh1824 sh2534 sh3544 sh4554 shwomen1864 shblack1864 shwhite1864 shasian1864 unemploy1864 wage1864 if yearold<2011, cluster(stateid) 

 foreach var of local varscon {

		
local claimcon`var'=_b[`var']
return scalar claimcon`var'=`claimcon`var''	
		
        }





**** post-enrollment

quietly sum mem_mo_ind_rel if yearold<2006 & MA==1
local preenr=r(mean)

*quietly sum lgac if yearold<2006 & MA==1


quietly sum prov_health_serv_incur_ind_year if yearold<2006 & MA==1
local preclaim=r(mean)

*quietly sum lgprem if yearold<2006 & MA==1
quietly sum prem_per_year_ind if yearold<2006 & MA==1
local preprem=r(mean)


sum(MA) 
local MAmean=r(mean)


return scalar Ipre=`preenr'
return scalar Claimpre=`preclaim'
return scalar Prempre=`preprem'
return scalar MAmean=`MAmean'





end


clear

set more off

# delimit ;

simulate  


premMAafter=r(premMAafter) premMAduring=r(premMAduring) premMA=r(premMA) premafter=r(premafter) premduring=r(premduring) premconstant=r(prem_cons)

premconMAafter=r(premconMAafter) premconMAduring=r(premconMAduring) premconMA=r(premconMA) premconafter=r(premconafter) premconduring=r(premconduring) 

premconsh1824=r(premconsh1824) premconsh2534=r(premconsh2534) premconsh3544=r(premconsh3544) premconsh4554=r(premconsh4554) premconshwomen1864=r(premconshwomen1864) 

premconshblack1864=r(premconshblack1864) premconshwhite1864=r(premconshwhite1864) premconshasian1864=r(premconshasian1864) premconunemploy1864=r(premconunemploy1864) premconwage1864=r(premconwage1864) premconconstant=r(premcon_cons) 



enrMAafter=r(enrMAafter) enrMAduring=r(enrMAduring) enrMA=r(enrMA) enrafter=r(enrafter) enrduring=r(enrduring)  enrconstant=r(enr_cons)

enrconMAafter=r(enrconMAafter) enrconMAduring=r(enrconMAduring) enrconMA=r(enrconMA) enrconafter=r(enrconafter) enrconduring=r(enrconduring) 

enrconsh1824=r(enrconsh1824) enrconsh2534=r(enrconsh2534) enrconsh3544=r(enrconsh3544) enrconsh4554=r(enrconsh4554) enrconshwomen1864=r(enrconshwomen1864) 

enrconshblack1864=r(enrconshblack1864) enrconshwhite1864=r(enrconshwhite1864) enrconshasian1864=r(enrconshasian1864) enrconunemploy1864=r(enrconunemploy1864) enrconwage1864=r(enrconwage1864) enrconconstant=r(enrcon_cons) 



claimMAafter=r(claimMAafter) claimMAduring=r(claimMAduring) claimMA=r(claimMA) claimafter=r(claimafter) claimduring=r(claimduring) claimconstant=r(claim_cons)

claimconMAafter=r(claimconMAafter) claimconMAduring=r(claimconMAduring) claimconMA=r(claimconMA) claimconafter=r(claimconafter) claimconduring=r(claimconduring) 

claimconsh1824=r(claimconsh1824) claimconsh2534=r(claimconsh2534) claimconsh3544=r(claimconsh3544) claimconsh4554=r(claimconsh4554) claimconshwomen1864=r(claimconshwomen1864) 

claimconshblack1864=r(claimconshblack1864) claimconshwhite1864=r(claimconshwhite1864) claimconshasian1864=r(claimconshasian1864) claimconunemploy1864=r(claimconunemploy1864) claimconwage1864=r(claimconwage1864) claimconconstant=r(claimcon_cons) 


enrpre=r(Ipre) MAmean=r(MAmean) prempre=r(Prempre) claimpre=r(Claimpre) ,  saving(Data\SNL\bootreg1demo, replace) reps(5000) seed(1111): bootreg1demo ;


# delimit cr



local MAvarlist "premMAafter premMAduring premMA claimMAafter claimMAduring claimMA enrMAafter enrMAduring enrMA premconMAafter premconMAduring premconMA claimconMAafter claimconMAduring claimconMA enrconMAafter enrconMAduring enrconMA"

foreach var of local MAvarlist {

replace `var'=. if MAmean==0

}
*** 


program drop bootreg1demo

label variable claimconMAafter "MA*After" 
label variable claimconMAduring "MA*During" 
label variable claimconMA "MA" 
label variable claimconafter "After"
label variable claimconduring "During"

label variable claimpre "Pre-Reform Value (levels)"
label variable claimconconstant "Constant"
label variable claimconsh1824 "Share 18-24"
label variable claimconsh2534 "Share 25-34"
label variable claimconsh3544 "Share 35-44"
label variable claimconsh4554 "Share 45-54"
label variable claimconshwomen1864 "Share Women"
label variable claimconshblack1864 "Share Black"
label variable claimconshwhite1864 "Share White"
label variable claimconshasian1864 "Share Asian"
label variable claimconunemploy1864 "Share Unemployed"
label variable claimconwage1864 "Avg. Wage"


****************************************************************************************************************************
***** Create TEX Table
****************************************************************************************************************************


local i=1
local j=1

local vars ""MAafter" "MAduring" "MA" "after" "during" "sh1824" "sh2534" "sh3544" "sh4554" "shwomen1864" "shblack1864" "shwhite1864" "shasian1864"  "unemploy1864" "wage1864" "constant""
local categs ""enr" "enrcon" "prem" "premcon" "claim" "claimcon"" 

# delimit ;
cap file close f ;
file open f using "${tabout}Data\Compiled\Tables\did-table-boot-demorob.tex" , write replace ;
file write f 

"{\begin{tabular}{lcccccc}" _n
"\hline\hline" _n

"&" _tab "(1)" _tab "&" _tab "(2)" _tab "&" _tab "(3)"  _tab "&" _tab "(4)" _tab "&" _tab "(5)" _tab "&" _tab "(6)" _tab "\\" _n
 
"&" _tab "Coverage" _tab "&" _tab "Coverage" _tab "&" _tab "Log Premium" _tab "&" _tab "Log Premium" _tab "&" _tab "Log Claim Exp" _tab "&" _tab "Log Claim Exp" _tab "\\" _n

"\hline" _n ;

# delimit cr
foreach vari of local vars {


foreach row of numlist 1 2 {



if `row'==1 {

file write f `"`: var label claimcon`vari''"' _tab 

local j=1


foreach col of local categs {

if `i'<6 | `i'==16 | `j'==2 | `j'==4 | `j'==6 {

local varname="`col'"+"`vari'"

**** stars

quietly centile `varname', centile(0.5 2.5 5 95 97.5 99.5)

  local s=""
  if `r(c_3)'*`r(c_4)'>0 local s="$^{*\ \ }$"
  if `r(c_2)'*`r(c_5)'>0 local s="$^{**\ }$"
  if `r(c_1)'*`r(c_6)'>0 local s="$^{***}$"
  
  
  

quietly centile `varname', centile(50)




*sum `col'`vari' 

if "`col'"=="enr"{

file write f "&" _tab %5.3f (meanestsrobcontrols[`i',`j']) "`s'"

			}
			
if "`col'"!="enr"{

file write f "&" _tab %5.3f (meanestsrobcontrols[`i',`j']) "`s'"

			}	
			
			

			
		
									}
									
if 	`i'>5 & `i'<16 & (`j'==1 | `j'==3 | `j'==5)		{

file write f "&" _tab

													} 	
local j=`j'+1	
								

								
						}

file write f "\\" _n			
								
			}

if `row'==2 {   

*** standard errors

local j=1



foreach col of local categs {

if `i'<6 | `i'==16 | `j'==2 | `j'==4 | `j'==6 {

local varname="`col'"+"`vari'"

quietly centile `varname', centile(2.5 97.5)


if "`col'"=="enr"{

file write f "&" _tab "[" %4.3f (`r(c_1)') ", " %4.3f (`r(c_2)') "]"

			}
			
if "`col'"!="enr"{

file write f "&" _tab "[" %4.3f (`r(c_1)') ", " %4.3f (`r(c_2)') "]"

			}		
			
											}

if 	`i'>5 & `i'<16 & (`j'==1 | `j'==3 | `j'==5)		{

file write f "&" _tab

													} 	
local j=`j'+1

											


							}
file write f "\\" _n

			}
							


						  }
local i=`i'+1						  
} 



file write f "\\" _n "\hline\hline" _n "\multicolumn{7}{l}{\footnotesize The bootsrapped 95\% confidence interval is displayed in brackets.}" _tab "\\" _n 
file write f "\multicolumn{7}{l}{\footnotesize  \parbox[t]{17cm}{Standard errors are block bootstrapped. Abadie weights depend on member month enrollment as well as changes in coverage, relative changes in average costs, and relative changes in premiums between 2004 and 2005. The additional control variables refer to the population of nonelderly adults aged 18-64.}}" _tab "\\" _n 
file write f "\multicolumn{7}{l}{\footnotesize $^{*}$ \(p<0.10\), $^{**}$ \(p<0.05\), $^{***}$ \(p<0.01\)}" _tab "\\" _n 
file write f "\end{tabular}" _tab "}"


file close f




